import { Feature, GeoJsonProperties, Point, LineString, Polygon } from 'geojson';
export interface KmlFolder {
    folder_id: string;
    name: string;
    parent_folder_id: string | null;
}
export interface KmlIconStyleProps {
    'icon-color'?: string;
    'icon-opacity'?: number;
    'icon-size'?: number;
    'icon-image'?: string;
    'text-color'?: string;
    'text-opacity'?: number;
    'text-size'?: number;
}
export interface KmlLineStyleProps {
    'line-color'?: string;
    'line-opacity'?: number;
    'line-width'?: number;
}
export interface KmlPolyStyleProps {
    'fill-color'?: string;
    'fill-opacity'?: number;
    'fill-outline-color'?: string;
}
export type KmlStyleProps = KmlIconStyleProps | KmlLineStyleProps | KmlPolyStyleProps;
export type KmlPointFeature<P = GeoJsonProperties> = Omit<Feature<Point, (P & KmlIconStyleProps)>, "bbox">;
export type KmlLineFeature<P = GeoJsonProperties> = Omit<Feature<LineString, (P & KmlLineStyleProps)>, "bbox">;
export type KmlPolyFeature<P = GeoJsonProperties> = Omit<Feature<Polygon, (P & KmlPolyStyleProps)>, "bbox">;
export type KmlFeature<P = GeoJsonProperties> = KmlPointFeature<P> | KmlLineFeature<P> | KmlPolyFeature<P>;
export interface KmlGeojson<P = GeoJsonProperties> {
    type: 'FeatureCollection';
    features: Array<KmlFeature<P>>;
}
export declare class KmlToGeojson {
    private include_altitude;
    constructor(altitude?: boolean);
    private readonly get1;
    private readonly kmlColor;
    private readonly parsePlacemark;
    private readonly parseFolder;
    private readonly parseNode;
    private readonly parseStyleNode;
    private readonly parseStyles;
    readonly parse: <T extends GeoJsonProperties = GeoJsonProperties>(kml_content: string) => {
        folders: KmlFolder[];
        geojson: KmlGeojson;
    };
}
